@@ -20,6 +20,7 @@ More info see html_parser.py !
 # ------------------------------------------------------------------- add start
 from __future__ import division, absolute_import, print_function, unicode_literals
 from mycms.creole.py3compat import PY3
+
 # --------------------------------------------------------------------- add end
 
 """A parser for HTML and XHTML."""
@@ -34,27 +35,27 @@ from mycms.creole.py3compat import PY3
 
 # --------------------------------------------------------------- changes start
 try:
-    import _markupbase # python 3
+    import _markupbase  # python 3
 except ImportError:
-    import markupbase as _markupbase # python 2
+    import markupbase as _markupbase  # python 2
 # --------------------------------------------------------------- changes end
 import re
 
 # Regular expressions used for parsing
 
-interesting_normal = re.compile('[&<]')
-incomplete = re.compile('&[a-zA-Z#]')
+interesting_normal = re.compile("[&<]")
+incomplete = re.compile("&[a-zA-Z#]")
 
-entityref = re.compile('&([a-zA-Z][-.a-zA-Z0-9]*)[^a-zA-Z0-9]')
-charref = re.compile('&#(?:[0-9]+|[xX][0-9a-fA-F]+)[^0-9a-fA-F]')
+entityref = re.compile("&([a-zA-Z][-.a-zA-Z0-9]*)[^a-zA-Z0-9]")
+charref = re.compile("&#(?:[0-9]+|[xX][0-9a-fA-F]+)[^0-9a-fA-F]")
 
-starttagopen = re.compile('<[a-zA-Z]')
-piclose = re.compile('>')
-commentclose = re.compile(r'--\s*>')
-tagfind = re.compile('([a-zA-Z][-.a-zA-Z0-9:_]*)(?:\s|/(?!>))*')
+starttagopen = re.compile("<[a-zA-Z]")
+piclose = re.compile(">")
+commentclose = re.compile(r"--\s*>")
+tagfind = re.compile("([a-zA-Z][-.a-zA-Z0-9:_]*)(?:\s|/(?!>))*")
 # see http://www.w3.org/TR/html5/tokenization.html#tag-open-state
 # and http://www.w3.org/TR/html5/tokenization.html#tag-name-state
-tagfind_tolerant = re.compile('[a-zA-Z][^\t\n\r\f />\x00]*')
+tagfind_tolerant = re.compile("[a-zA-Z][^\t\n\r\f />\x00]*")
 # Note:
 #  1) the strict attrfind isn't really strict, but we can't make it
 #     correctly strict without breaking backward compatibility;
@@ -62,12 +63,14 @@ tagfind_tolerant = re.compile('[a-zA-Z][^\t\n\r\f />\x00]*')
 #  3) if you change attrfind and/or locatestarttagend the parser will
 #     explode, so don't do it.
 attrfind = re.compile(
-    r'\s*([a-zA-Z_][-.:a-zA-Z_0-9]*)(\s*=\s*'
-    r'(\'[^\']*\'|"[^"]*"|[^\s"\'=<>`]*))?')
+    r"\s*([a-zA-Z_][-.:a-zA-Z_0-9]*)(\s*=\s*" r'(\'[^\']*\'|"[^"]*"|[^\s"\'=<>`]*))?'
+)
 attrfind_tolerant = re.compile(
     r'((?<=[\'"\s/])[^\s/>][^\s/=>]*)(\s*=+\s*'
-    r'(\'[^\']*\'|"[^"]*"|(?![\'"])[^>\s]*))?(?:\s|/(?!>))*')
-locatestarttagend = re.compile(r"""
+    r'(\'[^\']*\'|"[^"]*"|(?![\'"])[^>\s]*))?(?:\s|/(?!>))*'
+)
+locatestarttagend = re.compile(
+    r"""
   <[a-zA-Z][-.a-zA-Z0-9:_]*          # tag name
   (?:\s+                             # whitespace before attribute name
     (?:[a-zA-Z_][-.:a-zA-Z0-9_]*     # attribute name
@@ -80,8 +83,11 @@ locatestarttagend = re.compile(r"""
      )
    )*
   \s*                                # trailing whitespace
-""", re.VERBOSE)
-locatestarttagend_tolerant = re.compile(r"""
+""",
+    re.VERBOSE,
+)
+locatestarttagend_tolerant = re.compile(
+    r"""
   <[a-zA-Z][-.a-zA-Z0-9:_]*          # tag name
   (?:[\s/]*                          # optional whitespace before attribute name
     (?:(?<=['"\s/])[^\s/>][^\s/=>]*  # attribute name
@@ -95,11 +101,13 @@ locatestarttagend_tolerant = re.compile(r"""
      )*
    )?
   \s*                                # trailing whitespace
-""", re.VERBOSE)
-endendtag = re.compile('>')
+""",
+    re.VERBOSE,
+)
+endendtag = re.compile(">")
 # the HTML 5 spec, section 8.1.2.2, doesn't allow spaces between
 # </ and the tag name, so maybe this should be fixed
-endtagfind = re.compile('</\s*([a-zA-Z][-.a-zA-Z0-9:_]*)\s*>')
+endtagfind = re.compile("</\s*([a-zA-Z][-.a-zA-Z0-9:_]*)\s*>")
 
 
 class HTMLParseError(Exception):
@@ -155,8 +163,8 @@ class HTMLParser(_markupbase.ParserBase):
 
     def reset(self):
         """Reset this instance.  Loses all unprocessed data."""
-        self.rawdata = ''
-        self.lasttag = '???'
+        self.rawdata = ""
+        self.lasttag = "???"
         self.interesting = interesting_normal
         self.cdata_elem = None
         _markupbase.ParserBase.reset(self)
@@ -185,7 +193,7 @@ class HTMLParser(_markupbase.ParserBase):
 
     def set_cdata_mode(self, elem):
         self.cdata_elem = elem.lower()
-        self.interesting = re.compile(r'</\s*%s\s*>' % self.cdata_elem, re.I)
+        self.interesting = re.compile(r"</\s*%s\s*>" % self.cdata_elem, re.I)
 
     def clear_cdata_mode(self):
         self.interesting = interesting_normal
@@ -199,19 +207,21 @@ class HTMLParser(_markupbase.ParserBase):
         i = 0
         n = len(rawdata)
         while i < n:
-            match = self.interesting.search(rawdata, i) # < or &
+            match = self.interesting.search(rawdata, i)  # < or &
             if match:
                 j = match.start()
             else:
                 if self.cdata_elem:
                     break
                 j = n
-            if i < j: self.handle_data(rawdata[i:j])
+            if i < j:
+                self.handle_data(rawdata[i:j])
             i = self.updatepos(i, j)
-            if i == n: break
+            if i == n:
+                break
             startswith = rawdata.startswith
-            if startswith('<', i):
-                if starttagopen.match(rawdata, i): # < + letter
+            if startswith("<", i):
+                if starttagopen.match(rawdata, i):  # < + letter
                     k = self.parse_starttag(i)
                 elif startswith("</", i):
                     k = self.parse_endtag(i)
@@ -234,9 +244,9 @@ class HTMLParser(_markupbase.ParserBase):
                         break
                     if self.strict:
                         self.error("EOF in middle of construct")
-                    k = rawdata.find('>', i + 1)
+                    k = rawdata.find(">", i + 1)
                     if k < 0:
-                        k = rawdata.find('<', i + 1)
+                        k = rawdata.find("<", i + 1)
                         if k < 0:
                             k = i + 1
                     else:
@@ -249,22 +259,22 @@ class HTMLParser(_markupbase.ParserBase):
                     name = match.group()[2:-1]
                     self.handle_charref(name)
                     k = match.end()
-                    if not startswith(';', k-1):
+                    if not startswith(";", k - 1):
                         k = k - 1
                     i = self.updatepos(i, k)
                     continue
                 else:
-                    if ";" in rawdata[i:]: #bail by consuming &#
+                    if ";" in rawdata[i:]:  # bail by consuming &#
                         self.handle_data(rawdata[0:2])
                         i = self.updatepos(i, 2)
                     break
-            elif startswith('&', i):
+            elif startswith("&", i):
                 match = entityref.match(rawdata, i)
                 if match:
                     name = match.group(1)
                     self.handle_entityref(name)
                     k = match.end()
-                    if not startswith(';', k-1):
+                    if not startswith(";", k - 1):
                         k = k - 1
                     i = self.updatepos(i, k)
                     continue
@@ -300,20 +310,20 @@ class HTMLParser(_markupbase.ParserBase):
     # See also parse_declaration in _markupbase
     def parse_html_declaration(self, i):
         rawdata = self.rawdata
-        if rawdata[i:i+2] != '<!':
-            self.error('unexpected call to parse_html_declaration()')
-        if rawdata[i:i+4] == '<!--':
+        if rawdata[i : i + 2] != "<!":
+            self.error("unexpected call to parse_html_declaration()")
+        if rawdata[i : i + 4] == "<!--":
             # this case is actually already handled in goahead()
             return self.parse_comment(i)
-        elif rawdata[i:i+3] == '<![':
+        elif rawdata[i : i + 3] == "<![":
             return self.parse_marked_section(i)
-        elif rawdata[i:i+9].lower() == '<!doctype':
+        elif rawdata[i : i + 9].lower() == "<!doctype":
             # find the closing >
-            gtpos = rawdata.find('>', i+9)
+            gtpos = rawdata.find(">", i + 9)
             if gtpos == -1:
                 return -1
-            self.handle_decl(rawdata[i+2:gtpos])
-            return gtpos+1
+            self.handle_decl(rawdata[i + 2 : gtpos])
+            return gtpos + 1
         else:
             return self.parse_bogus_comment(i)
 
@@ -321,24 +331,24 @@ class HTMLParser(_markupbase.ParserBase):
     # see http://www.w3.org/TR/html5/tokenization.html#bogus-comment-state
     def parse_bogus_comment(self, i, report=1):
         rawdata = self.rawdata
-        if rawdata[i:i+2] not in ('<!', '</'):
-            self.error('unexpected call to parse_comment()')
-        pos = rawdata.find('>', i+2)
+        if rawdata[i : i + 2] not in ("<!", "</"):
+            self.error("unexpected call to parse_comment()")
+        pos = rawdata.find(">", i + 2)
         if pos == -1:
             return -1
         if report:
-            self.handle_comment(rawdata[i+2:pos])
+            self.handle_comment(rawdata[i + 2 : pos])
         return pos + 1
 
     # Internal -- parse processing instr, return end or -1 if not terminated
     def parse_pi(self, i):
         rawdata = self.rawdata
-        assert rawdata[i:i+2] == '<?', 'unexpected call to parse_pi()'
-        match = piclose.search(rawdata, i+2) # >
+        assert rawdata[i : i + 2] == "<?", "unexpected call to parse_pi()"
+        match = piclose.search(rawdata, i + 2)  # >
         if not match:
             return -1
         j = match.start()
-        self.handle_pi(rawdata[i+2: j])
+        self.handle_pi(rawdata[i + 2 : j])
         j = match.end()
         return j
 
@@ -353,8 +363,8 @@ class HTMLParser(_markupbase.ParserBase):
 
         # Now parse the data between i+1 and j into a tag and attrs
         attrs = []
-        match = tagfind.match(rawdata, i+1)
-        assert match, 'unexpected call to parse_starttag()'
+        match = tagfind.match(rawdata, i + 1)
+        assert match, "unexpected call to parse_starttag()"
         k = match.end()
         self.lasttag = tag = match.group(1).lower()
         while k < endpos:
@@ -367,8 +377,10 @@ class HTMLParser(_markupbase.ParserBase):
             attrname, rest, attrvalue = m.group(1, 2, 3)
             if not rest:
                 attrvalue = None
-            elif attrvalue[:1] == '\'' == attrvalue[-1:] or \
-                 attrvalue[:1] == '"' == attrvalue[-1:]:
+            elif (
+                attrvalue[:1] == "'" == attrvalue[-1:]
+                or attrvalue[:1] == '"' == attrvalue[-1:]
+            ):
                 attrvalue = attrvalue[1:-1]
             if attrvalue:
                 attrvalue = self.unescape(attrvalue)
@@ -380,16 +392,16 @@ class HTMLParser(_markupbase.ParserBase):
             lineno, offset = self.getpos()
             if "\n" in self.__starttag_text:
                 lineno = lineno + self.__starttag_text.count("\n")
-                offset = len(self.__starttag_text) \
-                         - self.__starttag_text.rfind("\n")
+                offset = len(self.__starttag_text) - self.__starttag_text.rfind("\n")
             else:
                 offset = offset + len(self.__starttag_text)
             if self.strict:
-                self.error("junk characters in start tag: %r"
-                           % (rawdata[k:endpos][:20],))
+                self.error(
+                    "junk characters in start tag: %r" % (rawdata[k:endpos][:20],)
+                )
             self.handle_data(rawdata[i:endpos])
             return endpos
-        if end.endswith('/>'):
+        if end.endswith("/>"):
             # XHTML-style empty tag: <span attr="value" />
             self.handle_startendtag(tag, attrs)
         else:
@@ -408,7 +420,7 @@ class HTMLParser(_markupbase.ParserBase):
             m = locatestarttagend_tolerant.match(rawdata, i)
         if m:
             j = m.end()
-            next = rawdata[j:j+1]
+            next = rawdata[j : j + 1]
             if next == ">":
                 return j + 1
             if next == "/":
@@ -428,8 +440,7 @@ class HTMLParser(_markupbase.ParserBase):
             if next == "":
                 # end of input
                 return -1
-            if next in ("abcdefghijklmnopqrstuvwxyz=/"
-                        "ABCDEFGHIJKLMNOPQRSTUVWXYZ"):
+            if next in ("abcdefghijklmnopqrstuvwxyz=/" "ABCDEFGHIJKLMNOPQRSTUVWXYZ"):
                 # end of input in or before attribute value, or we have the
                 # '/' from a '/>' ending
                 return -1
@@ -445,12 +456,12 @@ class HTMLParser(_markupbase.ParserBase):
     # Internal -- parse endtag, return end or -1 if incomplete
     def parse_endtag(self, i):
         rawdata = self.rawdata
-        assert rawdata[i:i+2] == "</", "unexpected call to parse_endtag"
-        match = endendtag.search(rawdata, i+1) # >
+        assert rawdata[i : i + 2] == "</", "unexpected call to parse_endtag"
+        match = endendtag.search(rawdata, i + 1)  # >
         if not match:
             return -1
         gtpos = match.end()
-        match = endtagfind.match(rawdata, i) # </ + tag + >
+        match = endtagfind.match(rawdata, i)  # </ + tag + >
         if not match:
             if self.cdata_elem is not None:
                 self.handle_data(rawdata[i:gtpos])
@@ -458,11 +469,11 @@ class HTMLParser(_markupbase.ParserBase):
             if self.strict:
                 self.error("bad end tag: %r" % (rawdata[i:gtpos],))
             # find the name: w3.org/TR/html5/tokenization.html#tag-name-state
-            namematch = tagfind_tolerant.match(rawdata, i+2)
+            namematch = tagfind_tolerant.match(rawdata, i + 2)
             if not namematch:
                 # w3.org/TR/html5/tokenization.html#end-tag-open-state
-                if rawdata[i:i+3] == '</>':
-                    return i+3
+                if rawdata[i : i + 3] == "</>":
+                    return i + 3
                 else:
                     return self.parse_bogus_comment(i)
             tagname = namematch.group().lower()
@@ -470,11 +481,11 @@ class HTMLParser(_markupbase.ParserBase):
             # Note: this is not 100% correct, since we might have things like
             # </tag attr=">">, but looking for > after tha name should cover
             # most of the cases and is much simpler
-            gtpos = rawdata.find('>', namematch.end())
+            gtpos = rawdata.find(">", namematch.end())
             self.handle_endtag(tagname)
-            return gtpos+1
+            return gtpos + 1
 
-        elem = match.group(1).lower() # script or style
+        elem = match.group(1).lower()  # script or style
         if self.cdata_elem is not None:
             if elem != self.cdata_elem:
                 self.handle_data(rawdata[i:gtpos])
@@ -527,63 +538,72 @@ class HTMLParser(_markupbase.ParserBase):
 
     # Internal -- helper to remove special character quoting
     entitydefs = None
+
     def unescape(self, s):
-        if '&' not in s:
+        if "&" not in s:
             return s
         # -------------------------------------------------------- change start
         if PY3:
+
             def replaceEntities(s):
                 s = s.groups()[0]
                 try:
                     if s[0] == "#":
                         s = s[1:]
-                        if s[0] in ['x','X']:
+                        if s[0] in ["x", "X"]:
                             c = int(s[1:], 16)
                         else:
                             c = int(s)
                         return chr(c)
                 except ValueError:
-                    return '&#'+ s +';'
+                    return "&#" + s + ";"
                 else:
                     # Cannot use name2codepoint directly, because HTMLParser
                     # supports apos, which is not part of HTML 4
                     import html.entities
+
                     if HTMLParser.entitydefs is None:
-                        entitydefs = HTMLParser.entitydefs = {'apos':"'"}
+                        entitydefs = HTMLParser.entitydefs = {"apos": "'"}
                         for k, v in html.entities.name2codepoint.items():
                             entitydefs[k] = chr(v)
                     try:
                         return self.entitydefs[s]
                     except KeyError:
-                        return '&'+s+';'
-    
-            return re.sub(r"&(#?[xX]?(?:[0-9a-fA-F]+|\w{1,8}));",
-                          replaceEntities, s, flags=re.ASCII)
+                        return "&" + s + ";"
+
+            return re.sub(
+                r"&(#?[xX]?(?:[0-9a-fA-F]+|\w{1,8}));",
+                replaceEntities,
+                s,
+                flags=re.ASCII,
+            )
         else:
+
             def replaceEntities(s):
                 s = s.groups()[0]
                 try:
                     if s[0] == "#":
                         s = s[1:]
-                        if s[0] in ['x','X']:
+                        if s[0] in ["x", "X"]:
                             c = int(s[1:], 16)
                         else:
                             c = int(s)
                         return unichr(c)
                 except ValueError:
-                    return '&#'+s+';'
+                    return "&#" + s + ";"
                 else:
                     # Cannot use name2codepoint directly, because HTMLParser supports apos,
                     # which is not part of HTML 4
                     import htmlentitydefs
+
                     if HTMLParser.entitydefs is None:
-                        entitydefs = HTMLParser.entitydefs = {'apos':"'"}
+                        entitydefs = HTMLParser.entitydefs = {"apos": "'"}
                         for k, v in htmlentitydefs.name2codepoint.iteritems():
                             entitydefs[k] = unichr(v)
                     try:
                         return self.entitydefs[s]
                     except KeyError:
-                        return '&'+s+';'
-    
+                        return "&" + s + ";"
+
             return re.sub(r"&(#?[xX]?(?:[0-9a-fA-F]+|\w{1,8}));", replaceEntities, s)
-        # -------------------------------------------------------- change end        
\ No newline at end of file
+        # -------------------------------------------------------- change end
