@@ -2,9 +2,9 @@
 from django.http import HttpResponse
 import json
 
-MIMEANY = '*/*'
-MIMEJSON = 'application/json'
-MIMETEXT = 'text/plain'
+MIMEANY = "*/*"
+MIMEJSON = "application/json"
+MIMETEXT = "text/plain"
 
 
 def response_mimetype(request):
@@ -12,8 +12,8 @@ def response_mimetype(request):
     what the client accepts, as available in the `HTTP_ACCEPT` header.
     request -- a HttpRequest instance.
     """
-    can_json = MIMEJSON in request.META['HTTP_ACCEPT']
-    can_json |= MIMEANY in request.META['HTTP_ACCEPT']
+    can_json = MIMEJSON in request.META["HTTP_ACCEPT"]
+    can_json |= MIMEANY in request.META["HTTP_ACCEPT"]
     return MIMEJSON if can_json else MIMETEXT
 
 
@@ -26,7 +26,8 @@ class JSONResponse(HttpResponse):
             content = {'key': 'value'}
             return JSONResponse(content, mimetype=response_mimetype(request))
     """
-    def __init__(self, obj='', json_opts=None, mimetype=MIMEJSON, *args, **kwargs):
+
+    def __init__(self, obj="", json_opts=None, mimetype=MIMEJSON, *args, **kwargs):
         json_opts = json_opts if isinstance(json_opts, dict) else {}
         content = json.dumps(obj, **json_opts)
-        super(JSONResponse, self).__init__(content, mimetype, *args, **kwargs)
\ No newline at end of file
+        super(JSONResponse, self).__init__(content, mimetype, *args, **kwargs)
