@@ -313,7 +313,7 @@ class CMSLoginView(View):
         next_page = request.GET.get("next", "")
 
         if not request.user.is_authenticated:
-            template_name = "mycms/Login.html"
+            template_name = "mycms/pages/Login.html"
 
             # also set a session variable to show the toolbar
             request.session["show_toolbar"] = True
@@ -370,7 +370,7 @@ class CMSLoginView(View):
 
 class CMSUserProfileView(View):
     def get(self, request, **kwargs):
-        template_name = "mycms/Profile.html"
+        template_name = "mycms/pages/Profile.html"
         if not request.user.is_authenticated:
             return HttpResponseRedirect("/login")
         else:
@@ -398,7 +398,7 @@ class CMSLogoutView(View):
 class CMSFrontPage(View):
     def get(self, request, **kwargs):
 
-        template_name = "mycms/Index.html"
+        template_name = "mycms/pages/Index.html"
 
         # TODO: Fix this hack. We create a fake view_object for the frontpage
         # so that we can pass a few template data.
@@ -408,7 +408,9 @@ class CMSFrontPage(View):
 
         view_object = View_Object()
 
-        if settings.FORCE_SHOW_ADVERTS or (settings.DEBUG == False):
+        show_adverts = getattr(settings, "FORCE_SHOW_ADVERTS", False)
+
+        if show_adverts or (settings.DEBUG == False):
             view_object.SHOW_ADVERTS = True
         else:
             print("SHOW_ADDS_IS FALSE")
